@@ -4,6 +4,7 @@ package font
 
 import (
 	"bytes"
+	"encoding/gob"
 	"fmt"
 	"path"
 	"strings"
@@ -11,6 +12,11 @@ import (
 	"github.com/ConradIrwin/font/sfnt"
 )
 
+func init() {
+	gob.Register([]*Font{})
+	gob.Register([]*Asset{})
+}
+
 // Font describes a font file and the various metadata associated with it.
 type Font struct {
 	Name     string                 `json:"name,omitempty" jsonschema:"title=Font name,description=The name of the font"`
