@@ -25,6 +25,7 @@ type SegmentWriter interface {
 
 func init() {
 	gob.Register(&segments.Angular{})
+	gob.Register(&segments.Version{})
 	gob.Register(&segments.Argocd{})
 	gob.Register(&segments.Aurelia{})
 	gob.Register(&segments.Aws{})
@@ -55,8 +56,13 @@ func init() {
 	gob.Register(&segments.Flutter{})
 	gob.Register(&segments.Fortran{})
 	gob.Register(&segments.Fossil{})
+	gob.Register(&segments.FossilStatus{})
 	gob.Register(&segments.Gcp{})
 	gob.Register(&segments.Git{})
+	gob.Register(&segments.GitStatus{})
+	gob.Register(&segments.Rebase{})
+	gob.Register(&segments.User{})
+	gob.Register(&segments.Commit{})
 	gob.Register(&segments.GitVersion{})
 	gob.Register(&segments.Golang{})
 	gob.Register(&segments.Haskell{})
@@ -65,12 +71,14 @@ func init() {
 	gob.Register(&segments.Java{})
 	gob.Register(&segments.HTTP{})
 	gob.Register(&segments.Jujutsu{})
+	gob.Register(&segments.JujutsuStatus{})
 	gob.Register(&segments.Julia{})
 	gob.Register(&segments.Kotlin{})
 	gob.Register(&segments.Kubectl{})
 	gob.Register(&segments.LastFM{})
 	gob.Register(&segments.Lua{})
 	gob.Register(&segments.Mercurial{})
+	gob.Register(&segments.MercurialStatus{})
 	gob.Register(&segments.Mojo{})
 	gob.Register(&segments.Mvn{})
 	gob.Register(&segments.Nba{})
@@ -85,20 +93,24 @@ func init() {
 	gob.Register(&segments.Os{})
 	gob.Register(&segments.Owm{})
 	gob.Register(&segments.Path{})
+	gob.Register(&segments.Folders{})
 	gob.Register(&segments.Perl{})
 	gob.Register(&segments.Php{})
 	gob.Register(&segments.Plastic{})
+	gob.Register(&segments.PlasticStatus{})
 	gob.Register(&segments.Pnpm{})
 	gob.Register(&segments.Project{})
 	gob.Register(&segments.Pulumi{})
 	gob.Register(&segments.Python{})
 	gob.Register(&segments.Quasar{})
+	gob.Register(&segments.Package{})
 	gob.Register(&segments.R{})
 	gob.Register(&segments.React{})
 	gob.Register(&segments.Root{})
 	gob.Register(&segments.Ruby{})
 	gob.Register(&segments.Rust{})
 	gob.Register(&segments.Sapling{})
+	gob.Register(&segments.SaplingStatus{})
 	gob.Register(&segments.Session{})
 	gob.Register(&segments.Shell{})
 	gob.Register(&segments.Sitecore{})
@@ -107,6 +119,7 @@ func init() {
 	gob.Register(&segments.Strava{})
 	gob.Register(&segments.Svelte{})
 	gob.Register(&segments.Svn{})
+	gob.Register(&segments.SvnStatus{})
 	gob.Register(&segments.Swift{})
 	gob.Register(&segments.SystemInfo{})
 	gob.Register(&segments.TalosCTL{})
@@ -118,6 +131,7 @@ func init() {
 	gob.Register(&segments.Umbraco{})
 	gob.Register(&segments.Unity{})
 	gob.Register(&segments.Upgrade{})
+	gob.Register(&segments.UpgradeCache{})
 	gob.Register(&segments.V{})
 	gob.Register(&segments.Vala{})
 	gob.Register(&segments.Wakatime{})
@@ -127,6 +141,7 @@ func init() {
 	gob.Register(&segments.Yarn{})
 	gob.Register(&segments.Ytm{})
 	gob.Register(&segments.Zig{})
+	gob.Register(&segments.Segment{})
 }
 
 const (
