@@ -615,7 +615,8 @@ func (g *Git) getGitConfig() (*ini.File, error) {
 			return
 		}
 
-		cfg, err := ini.Load(configData)
+		// ini.Load expects []byte to parse content, not a file path
+		cfg, err := ini.Load([]byte(configData))
 		if err != nil {
 			g.configErr = err
 			return
