@@ -1,7 +1,7 @@
 package segments
 
 type Rust struct {
-	language
+	Language
 }
 
 func (r *Rust) Template() string {
@@ -18,5 +18,5 @@ func (r *Rust) Enabled() bool {
 		},
 	}
 
-	return r.language.Enabled()
+	return r.Language.Enabled()
 }
