@@ -4,12 +4,10 @@ import (
 	"strings"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 type Shell struct {
-	props properties.Properties
-	env   runtime.Environment
+	Base
 
 	Name    string
 	Version string
@@ -36,8 +34,3 @@ func (s *Shell) Enabled() bool {
 	}
 	return true
 }
-
-func (s *Shell) Init(props properties.Properties, env runtime.Environment) {
-	s.props = props
-	s.env = env
-}
