@@ -13,13 +13,13 @@ import (
 
 func TestSysInfo(t *testing.T) {
 	cases := []struct {
+		Error          error
 		Case           string
 		ExpectedString string
-		ExpectDisabled bool
+		Template       string
 		SysInfo        runtime.SystemInfo
 		Precision      int
-		Template       string
-		Error          error
+		ExpectDisabled bool
 	}{
 		{
 			Case:           "Error",
@@ -74,6 +74,17 @@ func TestSysInfo(t *testing.T) {
 				},
 			},
 		},
+		{
+			Case:           "accurate memory percentage",
+			ExpectedString: "36.96",
+			SysInfo: runtime.SystemInfo{
+				Memory: runtime.Memory{
+					PhysicalPercentUsed: 36.96,
+				},
+			},
+			Precision: 2,
+			Template:  "{{ round .PhysicalPercentUsed .Precision }}",
+		},
 	}
 
 	for _, tc := range cases {
